@@ -1,14 +1,17 @@
 __title__ = 'PyBlox2'
 __author__ = 'Kyando'
 __license__ = 'MIT'
+__version__ = '1.0.0'
 
+import logging
 
-from .RobloxWebClient import BloxClient
-from .General import BloxUser
-from .General import BloxType
-from .Errors import RobloxApiError, PyBloxException
+from .Client import BloxClient
+from .User import BloxUser
+from .Errors import *
 from .Groups import BloxGroup
 from .Member import BloxMember
 from .Ranks import BloxRank
 from .Settings import BloxSettings
-from .Base import BloxType
\ No newline at end of file
+from .Base import BloxType
+
+logging.getLogger(__name__)
\ No newline at end of file
